1.0.2 (2020-04-15)
---------------------
* packaging restructure
* imports reordering for bug fix

1.0.1 (2020-04-15)
---------------------
* Updated README.rst with usage examples

1.0.0 (2020-04-15)
---------------------
* code cleanup

0.0.1 (2020-04-15)
---------------------
* Added connector to send API requests to Tcpwave's IPAM
* First release on PyPI.
* Supports operation as follows:
    * Create/list/detail/delete Network
    * Create/list/detail/delete Subnet
    * Fetches Next Available IP in the Subnet
    * Create/delete IP Object